@@ -45,10 +45,6 @@ HUB.Members.Profile = {
 		
 		//edit profile section if we have section specified in window hash
 		HUB.Members.Profile.editProfileSectionWithHash();
-		
-		//profile address section
-		HUB.Members.Profile.addresses();
-		HUB.Members.Profile.locateMe();
 	},
 	
 	//-------------------------------------------------------------
@@ -189,9 +185,7 @@ HUB.Members.Profile = {
 				{
 					switch( profile_field )
 					{
-						case 'email':
-						case 'usageAgreement':
-							HUB.Members.Profile.editRedirect(window.location.href);		break;
+						case 'email': 	HUB.Members.Profile.editRedirect(window.location.href);		break;
 						default: 		HUB.Members.Profile.editReloadSections();
 					}
 				}
@@ -217,8 +211,7 @@ HUB.Members.Profile = {
 	editBiographyConvert: function()
 	{
 		//if we have any active wykiwyg editors we want to auto-convert html to wiki before submitting
-		if (typeof(wykiwygs) === 'undefined') 
-		{
+		if (typeof(wykiwygs) === 'undefined') {
 			return;
 		}
 		if (wykiwygs.length) 
@@ -231,27 +224,41 @@ HUB.Members.Profile = {
 	},
 
 	//-------------------------------------------------------------
-	
+
 	editBiographyEditorReinstantiate: function()
 	{
 		var $ = this.jQuery;
 		
 		if ($("#profile_bio").length)
 		{
-			//reset wiki toolbar editor
-			if (typeof(wyktoolbar) !== 'undefined') 
+			if (typeof(wykiwygs) === 'undefined') 
 			{
-				wyktoolbar   = [];
+				if(HUB.Plugins.WikiEditorToolbar)
+				{
+					HUB.Plugins.WikiEditorToolbar.initialize();
+				}
 			}
-			
-			//reset wiki wysiwyg editor
-			if (typeof(wykiwygs) !== 'undefined') 
+			else
 			{
-				wykiwygs   = [];
+				var edtr = new WYKIWYG.editor.edit('editor',{
+					id: "profile_bio",
+					controls: [
+								'bold','italic','underline','strikethrough','|',
+								'subscript','superscript','|',
+								'orderedlist','unorderedlist','|',
+								'outdent','indent','|',
+								'unformat','|',
+								'style','|',
+								'hr','link','unlink'
+							],
+					footer: true,
+					toggle: true,
+					resize: true,
+					xhtml: true,
+					cssfile: '/plugins/hubzero/wikieditorwykiwyg/wikieditorwykiwyg.css'
+				});
+				wykiwygs.push(edtr);
 			}
-			
-			//call ajaxLoad which triggers re-apply
-			jQuery(document).trigger('ajaxLoad');
 		}
 	},
 	
@@ -304,22 +311,14 @@ HUB.Members.Profile = {
 		$.fancybox.close();
 		
 		//check to see if we are edit our profile or we were forced to fill in fields due to registration update
-		if(window.location.pathname.match(/\/members\/\d+\/profile/g) || !$('.member-update-missing').length)
+		if(window.location.pathname.match(/\/members\/\d+\/profile/g))
 		{
-			if (window.location.protocol + '//' + window.location.host + '/' == window.location.href)
-			{
-				HUB.Members.Profile.editRedirect(window.location.href);
-				return;
-			}
-			
 			//show updating overlay
 			HUB.Members.Profile.editShowUpdatingOverlay(".member_profile");
-
-			var url = $('#profile-page-content').attr('data-url');
-
-			$(".member_profile").load(url + " #profile-page-content", function() {
+			
+			$(".member_profile").load(window.location.href + " #profile-page-content", function() {
 				//reload page header in case we edited name
-				$("#page_header").load(url +  " #page_header > *");
+				$("#page_header").load(window.location.href +  " #page_header > *");
 			
 				//show edit links
 				$(".section-edit a").show();
@@ -429,17 +428,25 @@ HUB.Members.Profile = {
 			var w = $identity.find("img").width() + 2;
 			w = (w < 165) ? 165 : w;
 			
-			$change
-				.css('width',  w)
-				.attr("href", window.location.href.replace("profile","ajaxupload"))
-				.appendTo($identity);
+			$identity.find("img").load(function(){
+				$change
+					.css('width',  w)
+					.attr("href", window.location.href.replace("profile","ajaxupload"))
+					.appendTo($identity);
 					
-			//edit picture	
-			$('.com_members')
-				.on("click", "#page_identity_change", function(event) {
-					HUB.Members.Profile.editProfilePicturePopup();
-					event.preventDefault();
-				});	
+				//edit picture	
+				$('.com_members')
+					.on("mouseenter", "#page_identity", function(event) {
+						//$change.fadeIn("slow");
+					})
+					.on("mouseleave", "#page_identity", function(event) {
+						//$change.fadeOut("slow");
+					})
+					.on("click", "#page_identity_change", function(event) {
+						HUB.Members.Profile.editProfilePicturePopup();
+						event.preventDefault();
+					});
+			});	
 		}
 	},
 	
@@ -560,10 +567,9 @@ HUB.Members.Profile = {
 			
 			$.fancybox({
 				type:'inline',
-				autoSize: false, 
+				autoSize:false, 
 				modal: true,
 				width: 600,
-				height: 'auto',
 				content:$("#usage-agreement-popup"),
 				beforeLoad: function() 
 				{
@@ -634,152 +640,7 @@ HUB.Members.Profile = {
 				}, 800);
 			}
 		}
-	},
-	
-	addresses: function()
-	{
-		var $ = this.jQuery;
-		
-		//delete confirmation
-		$('.com_members').on('click','.delete-address', function(event) {
-			if (!confirm("Are you sure you want to delete this member Address?"))
-			{
-				event.preventDefault();
-			}
-		});
-		
-		//add/edit addresses
-		$('.add-address, .edit-address').fancybox({
-			type: 'ajax',
-			width: 700,
-			height: 'auto',
-			autoSize: false,
-			fitToView: false,  
-			titleShow: false,
-			tpl: {
-				wrap:'<div class="fancybox-wrap"><div class="fancybox-skin"><div class="fancybox-outer"><div id="sbox-content" class="fancybox-inner"></div></div></div></div>'
-			},
-			beforeLoad: function() {
-				href = $(this).attr('href');
-				if (href.indexOf('?') == -1) {
-					href += '?no_html=1';
-				} else {
-					href += '&no_html=1';
-				}
-				$(this).attr('href', href);
-			},
-			afterShow: function() {
-				if ($('#hubForm-ajax')) {
-					$('#hubForm-ajax').submit(function(e) {
-						e.preventDefault();
-						$.post($(this).attr('action'),$(this).serialize(), function(data) {
-							$.fancybox.close();
-							HUB.Members.Profile.editReloadSections();
-						});
-					});
-				}
-			}
-		});
-	},
-	
-	locateMe: function()
-	{
-		var $ = this.jQuery;
-		
-		//locate me
-		$('body').on('click', '#locate-me', function(event) {
-			event.preventDefault();
-			
-			//make sure we have the ability
-			if (!navigator.geolocation) 
-			{
-				alert('You browser is not capable of gettting you location.');
-				return;
-			}
-				
-			//use the browser geo location
-			navigator.geolocation.getCurrentPosition(
-				HUB.Members.Profile.locateMeGotLocation,
-				HUB.Members.Profile.locateMeGotError,
-				{
-					enableHighAccuracy: true,
-					timeout: 1000 * 5,
-					maximumAge: 0
-				}
-			);
-		});
-	},
-	
-	locateMeGotLocation: function( location )
-	{
-		var $ = HUB.Members.Profile.jQuery;
-		
-		var latitude      = location.coords.latitude,
-			longitude     = location.coords.longitude,
-			reverseGeoUrl = 'https://maps.google.com/maps/api/geocode/json?sensor=true&latlng=' + latitude + ',' + longitude;
-		
-		var address_parts = [];
-		
-		$.getJSON(reverseGeoUrl, function(json){
-			var result = json.results[0].address_components;
-			
-			for (var i=0, n=result.length; i<n; i++)
-			{
-				//do we have a street
-				if (jQuery.inArray('street_number', result[i].types) > -1)
-				{
-					address_parts['address1'] = result[i].long_name;
-				}
-				
-				//do we have a street
-				if (jQuery.inArray('route', result[i].types) > -1)
-				{
-					address_parts['address1'] += ' ' + result[i].long_name;
-				}
-				
-				//do we have a state / region
-				if (jQuery.inArray('locality', result[i].types) > -1)
-				{
-					address_parts['city'] = result[i].long_name;
-				}
-				
-				//do we have a state / region
-				if (jQuery.inArray('administrative_area_level_1', result[i].types) > -1)
-				{
-					address_parts['region'] = result[i].long_name;
-				}
-				
-				//do we have a postal code
-				if (jQuery.inArray('postal_code', result[i].types) > -1)
-				{
-					address_parts['postal'] = result[i].long_name;
-				}
-				
-				//do we have a country
-				if (jQuery.inArray('country', result[i].types) > -1)
-				{
-					address_parts['country'] = result[i].long_name.toUpperCase();
-				}
-			}
-			
-			//set values
-			$('.member-address-form').find('#address1').val(address_parts['address1']);
-			$('.member-address-form').find('#addressCity').val(address_parts['city']);
-			$('.member-address-form').find('#addressRegion').val(address_parts['region']);
-			$('.member-address-form').find('#addressPostal').val(address_parts['postal']);
-			$('.member-address-form').find('#addressCountry').val(address_parts['country']);
-			$('.member-address-form').find('#addressLatitude').val(latitude);
-			$('.member-address-form').find('#addressLongitude').val(longitude);
-		});
-	},
-	
-	locateMeGotError: function( error )
-	{
-		var $ = HUB.Members.Profile.jQuery;
-		
-		alert('Geo Location Error: ' + error.message);
 	}
-	
 };
 
 //-------------------------------------------------------------
