@@ -160,22 +160,22 @@ HUB.Plugins.ResourcesFavorite = {
 		var $ = this.jQuery;
 		
 		// Add to favorites
-		var fav = $('#favr-this');
+		var fav = $('#fav-this');
 		if ($(fav)) {
 			$(fav).bind('click', function(e) {
 				e.preventDefault();
 				
 				var rid = $('#rid').val();
-				$.get('index.php?option=com_resources&task=plugin&trigger=onResourcesFavorite&active=favorite&no_html=1&rid='+rid, {}, function(data) {
-					$('#favr-this').html(data);
-
+				$.get('index.php?option=com_resources&task=plugin&trigger=onResourcesFavorite&no_html=1&rid='+rid, {}, function(data) {
+					$('#fav-this').html(data);
+					
 					if ($(fav).hasClass('faved')) {
 						$(fav).removeClass('faved');
-						var img = '/components/com_resources/assets/img/broken-heart.gif';
+						var img = '/components/com_resources/images/broken-heart.gif';
 						var txt = 'Favorite removed.';
 					} else {
 						fav.addClass('faved');
-						var img = '/components/com_resources/assets/img/heart.gif';
+						var img = '/components/com_resources/images/heart.gif';
 						var txt = 'Favorite saved.';
 					}
 					$.growl(txt, '', img);
