@@ -68,13 +68,13 @@ class plgYSearchForum extends YSearchPlugin
 			$addtl_where[] = "(f.title NOT LIKE '%$forb%' AND f.comment NOT LIKE '%$forb%')";
 		}
 		
-		$juser = JFactory::getUser();
+		$juser =& JFactory::getUser();
 		if (version_compare(JVERSION, '1.6', 'ge'))
 		{
 			$gids = $authz->get_group_ids();
 			if (!$juser->authorise('core.view', 'com_groups'))
 			{
-				$addtl_where[] = 'f.scope_id IN (0' . ($gids ? ',' . join(',', $gids) : '') . ')';
+				$addtl_where[] = 'f.group_id IN (0' . ($gids ? ',' . join(',', $gids) : '') . ')';
 			}
 			else 
 			{
@@ -82,7 +82,7 @@ class plgYSearchForum extends YSearchPlugin
 
 				if ($gids)
 				{
-					$addtl_where[] = '(f.access IN (' . $viewlevels . ') OR ((f.access = 4 OR f.access = 5) AND f.scope_id IN (0,' . join(',', $gids) . ')))';
+					$addtl_where[] = '(f.access IN (' . $viewlevels . ') OR ((f.access = 4 OR f.access = 5) AND f.group_id IN (0,' . join(',', $gids) . ')))';
 				}
 				else 
 				{
@@ -101,7 +101,7 @@ class plgYSearchForum extends YSearchPlugin
 				$groups = array_map('intval', $authz->get_group_ids());
 				if ($groups)
 				{
-					$addtl_where[] = '(f.access = 0 OR f.access = 1 OR ((f.access = 3 OR f.access = 4) AND f.scope_id IN (0,' . join(',', $groups) . ')))';
+					$addtl_where[] = '(f.access = 0 OR f.access = 1 OR ((f.access = 3 OR f.access = 4) AND f.group_id IN (0,' . join(',', $groups) . ')))';
 				}
 				else
 				{
@@ -113,22 +113,22 @@ class plgYSearchForum extends YSearchPlugin
 		$rows = new YSearchResultSQL(
 			"SELECT 
 				f.title,
-				coalesce(f.comment, '') AS description, f.scope_id, s.alias as sect, c.alias as cat, CASE WHEN f.parent > 0 THEN f.parent ELSE f.id END as thread,
-				(CASE WHEN f.scope_id > 0 AND f.scope='group' THEN
-					concat('index.php?option=com_groups&cn=', g.cn, '&active=forum')
+				coalesce(f.comment, '') AS description, f.group_id, s.alias as sect, c.alias as cat, CASE WHEN f.parent > 0 THEN f.parent ELSE f.id END as thread,
+				(CASE WHEN f.group_id > 0 THEN
+					concat('/groups/', g.cn, '/forum/')
 				ELSE
-					concat('index.php?option=com_forum&section=', coalesce(concat(s.alias, '&category=', coalesce(concat(c.alias, '&thread='), ''))), CASE WHEN f.parent > 0 THEN f.parent ELSE f.id END)
+					concat('/forum/', coalesce(concat(s.alias, '/', coalesce(concat(c.alias, '/'), ''))), CASE WHEN f.parent > 0 THEN f.parent ELSE f.id END)
 				END) AS link,
 				$weight AS weight,
 				f.created AS date,
 				concat(s.alias, ', ', c.alias) AS section
-			FROM #__forum_posts f
-			LEFT JOIN #__forum_categories c 
+			FROM jos_forum_posts f
+			LEFT JOIN jos_forum_categories c 
 				ON c.id = f.category_id
-			LEFT JOIN #__forum_sections s
+			LEFT JOIN jos_forum_sections s
 				ON s.id = c.section_id
-			LEFT JOIN #__xgroups g
-				ON g.gidNumber = f.scope_id
+			LEFT JOIN jos_xgroups g
+				ON g.gidNumber = f.group_id
 			WHERE 
 				f.state = 1 AND 
 				$weight > 0".
@@ -141,7 +141,7 @@ class plgYSearchForum extends YSearchPlugin
 			{
 				continue;
 			}
-			if ($row->scope_id)
+			if ($row->group_id)
 			{
 				$row->link .= ($row->sect ? $row->sect : 'defaultsection') . '/';
 				$row->link .= ($row->cat ? $row->cat : 'discussion') . '/';
