@@ -97,13 +97,13 @@ class plgYSearchKB extends YSearchPlugin
 					WHEN c.alias IS NULL THEN s.alias
 					ELSE concat(s.alias, ', ', c.alias) 
 				END AS section
-			FROM #__faq f
-			LEFT JOIN #__faq_categories s 
+			FROM jos_faq f
+			LEFT JOIN jos_faq_categories s 
 				ON s.id = f.section
-			LEFT JOIN #__faq_categories c
+			LEFT JOIN jos_faq_categories c
 				ON c.id = f.category
 			WHERE 
-				f.state = 1 AND s.state = 1 AND 
+				f.state = 1 AND 
 				$weight > 0".
 				($addtl_where ? ' AND ' . join(' AND ', $addtl_where) : '') .
 			" ORDER BY $weight DESC"
